# Sample code: Load two images from buffers (from OpenCV Mat), extract feature vectors and compare similarity

import tfsdk
import os

options = tfsdk.ConfigurationOptions()
# Can set configuration options here
# ex:
# options.smallest_face_height = 40
# options.fd_mode = tfsdk.FACEDETECTIONMODE.VERSATILE
# options.fd_filter = tfsdk.FACEDETECTIONFILTER.BALANCED
# options.fr_model = tfsdk.FACIALRECOGNITIONMODEL.FULL

sdk = tfsdk.SDK(options)

# TODO: export your license token as TRUEFACE_TOKEN environment variable
is_valid = sdk.set_license(os.environ['TRUEFACE_TOKEN'])
if (is_valid == False):
	print("Invalid License Provided")
	print("Be sure to export your license token as TRUEFACE_TOKEN")
	quit()

import cv2
# Read the two images into buffers for the demonstration
cv_img_1 = cv2.imread("../images/armstrong_1.jpg")
cv_img_2 = cv2.imread("../images/armstrong_2.jpg")

# Set the first image of Armstrong from buffer
# OpenCV reads images as BGR
res = sdk.set_image(cv_img_1, cv_img_1.shape[1], cv_img_1.shape[0], tfsdk.COLORCODE.bgr)
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to set image 1")
	quit()

# Extract the feature vector
res, v1 = sdk.get_largest_face_feature_vector()
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to generate feature vector 1")
	quit()

# Set the second iamge of Armstrong
res = sdk.set_image(cv_img_2, cv_img_2.shape[1], cv_img_2.shape[0], tfsdk.COLORCODE.bgr)
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to set image 2")
	quit()

res, v2 = sdk.get_largest_face_feature_vector()
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to generate feature vector 2")
	quit()

res, match_probability, similarity = sdk.get_similarity(v1, v2)
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to compute similarity")
	quit()

print("Match Probability: ", match_probability)
print("Simlarity Score: ", similarity)


